==> zio-aws-mediapackagevod_3-5.17.158.2-sources.jar: zio/aws/mediapackagevod/model/AssetShallow.scala <==
package zio.aws.mediapackagevod.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mediapackagevod.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class AssetShallow(
    arn: Option[__string] = None,
    createdAt: Option[__string] = None,
    id: Option[__string] = None,
    packagingGroupId: Option[__string] = None,
    resourceId: Option[__string] = None,
    sourceArn: Option[__string] = None,
    sourceRoleArn: Option[__string] = None,
    tags: Option[Map[__string, __string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagevod.model.AssetShallow = {
    import AssetShallow.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(createdAt.map(value => value: java.lang.String))(
        _.createdAt
      )
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(packagingGroupId.map(value => value: java.lang.String))(
        _.packagingGroupId
      )
      .optionallyWith(resourceId.map(value => value: java.lang.String))(
        _.resourceId
      )
      .optionallyWith(sourceArn.map(value => value: java.lang.String))(
        _.sourceArn
      )
      .optionallyWith(sourceRoleArn.map(value => value: java.lang.String))(
        _.sourceRoleArn
      )
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.mediapackagevod.model.AssetShallow.ReadOnly =
    zio.aws.mediapackagevod.model.AssetShallow.wrap(buildAwsValue())
}
object AssetShallow {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackagevod.model.AssetShallow =
      zio.aws.mediapackagevod.model.AssetShallow(
        arn.map(value => value),
        createdAt.map(value => value),
        id.map(value => value),
        packagingGroupId.map(value => value),
        resourceId.map(value => value),
        sourceArn.map(value => value),
        sourceRoleArn.map(value => value),
        tags.map(value => value)
      )
    def arn: Option[__string]
    def createdAt: Option[__string]
    def id: Option[__string]
    def packagingGroupId: Option[__string]
    def resourceId: Option[__string]
    def sourceArn: Option[__string]
    def sourceRoleArn: Option[__string]
    def tags: Option[Map[__string, __string]]
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
    def getPackagingGroupId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("packagingGroupId", packagingGroupId)
    def getResourceId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("resourceId", resourceId)
    def getSourceArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceArn", sourceArn)
    def getSourceRoleArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceRoleArn", sourceRoleArn)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ) extends zio.aws.mediapackagevod.model.AssetShallow.ReadOnly {
    override val arn: Option[__string] =
      scala.Option(impl.arn()).map(value => value: __string)
    override val createdAt: Option[__string] =
      scala.Option(impl.createdAt()).map(value => value: __string)
    override val id: Option[__string] =
      scala.Option(impl.id()).map(value => value: __string)
    override val packagingGroupId: Option[__string] =
      scala.Option(impl.packagingGroupId()).map(value => value: __string)
    override val resourceId: Option[__string] =
      scala.Option(impl.resourceId()).map(value => value: __string)
    override val sourceArn: Option[__string] =
      scala.Option(impl.sourceArn()).map(value => value: __string)
    override val sourceRoleArn: Option[__string] =
      scala.Option(impl.sourceRoleArn()).map(value => value: __string)
    override val tags: Option[Map[__string, __string]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ): zio.aws.mediapackagevod.model.AssetShallow.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediapackagevod_3-5.19.31.1-sources.jar: zio/aws/mediapackagevod/model/AssetShallow.scala <==
package zio.aws.mediapackagevod.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mediapackagevod.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AssetShallow(
    arn: Optional[__string] = Optional.Absent,
    createdAt: Optional[__string] = Optional.Absent,
    id: Optional[__string] = Optional.Absent,
    packagingGroupId: Optional[__string] = Optional.Absent,
    resourceId: Optional[__string] = Optional.Absent,
    sourceArn: Optional[__string] = Optional.Absent,
    sourceRoleArn: Optional[__string] = Optional.Absent,
    tags: Optional[Map[__string, __string]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagevod.model.AssetShallow = {
    import AssetShallow.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(createdAt.map(value => value: java.lang.String))(
        _.createdAt
      )
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(packagingGroupId.map(value => value: java.lang.String))(
        _.packagingGroupId
      )
      .optionallyWith(resourceId.map(value => value: java.lang.String))(
        _.resourceId
      )
      .optionallyWith(sourceArn.map(value => value: java.lang.String))(
        _.sourceArn
      )
      .optionallyWith(sourceRoleArn.map(value => value: java.lang.String))(
        _.sourceRoleArn
      )
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.mediapackagevod.model.AssetShallow.ReadOnly =
    zio.aws.mediapackagevod.model.AssetShallow.wrap(buildAwsValue())
}
object AssetShallow {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackagevod.model.AssetShallow =
      zio.aws.mediapackagevod.model.AssetShallow(
        arn.map(value => value),
        createdAt.map(value => value),
        id.map(value => value),
        packagingGroupId.map(value => value),
        resourceId.map(value => value),
        sourceArn.map(value => value),
        sourceRoleArn.map(value => value),
        tags.map(value => value)
      )
    def arn: Optional[__string]
    def createdAt: Optional[__string]
    def id: Optional[__string]
    def packagingGroupId: Optional[__string]
    def resourceId: Optional[__string]
    def sourceArn: Optional[__string]
    def sourceRoleArn: Optional[__string]
    def tags: Optional[Map[__string, __string]]
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
    def getPackagingGroupId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("packagingGroupId", packagingGroupId)
    def getResourceId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("resourceId", resourceId)
    def getSourceArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceArn", sourceArn)
    def getSourceRoleArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceRoleArn", sourceRoleArn)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ) extends zio.aws.mediapackagevod.model.AssetShallow.ReadOnly {
    override val arn: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => value: __string)
    override val createdAt: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => value: __string)
    override val id: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: __string)
    override val packagingGroupId: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.packagingGroupId())
      .map(value => value: __string)
    override val resourceId: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceId())
      .map(value => value: __string)
    override val sourceArn: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceArn())
      .map(value => value: __string)
    override val sourceRoleArn: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceRoleArn())
      .map(value => value: __string)
    override val tags: Optional[Map[__string, __string]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagevod.model.AssetShallow
  ): zio.aws.mediapackagevod.model.AssetShallow.ReadOnly = new Wrapper(impl)
}
